@@ -16,8 +16,9 @@
 #' @export
 #' @name scale_colour_brewer_interactive
 #' @family interactive scale
-scale_colour_brewer_interactive <- function(...)
+scale_colour_brewer_interactive <- function(...) {
   scale_interactive(scale_colour_brewer, ...)
+}
 
 #' @export
 #' @rdname scale_colour_brewer_interactive
@@ -25,13 +26,15 @@ scale_color_brewer_interactive <- scale_colour_brewer_interactive
 
 #' @export
 #' @rdname scale_colour_brewer_interactive
-scale_fill_brewer_interactive <- function(...)
+scale_fill_brewer_interactive <- function(...) {
   scale_interactive(scale_fill_brewer, ...)
+}
 
 #' @export
 #' @rdname scale_colour_brewer_interactive
-scale_colour_distiller_interactive <- function(...)
+scale_colour_distiller_interactive <- function(...) {
   scale_interactive(scale_colour_distiller, ...)
+}
 
 #' @export
 #' @rdname scale_colour_brewer_interactive
@@ -39,13 +42,15 @@ scale_color_distiller_interactive <- scale_colour_distiller_interactive
 
 #' @export
 #' @rdname scale_colour_brewer_interactive
-scale_fill_distiller_interactive <- function(...)
+scale_fill_distiller_interactive <- function(...) {
   scale_interactive(scale_fill_distiller, ...)
+}
 
 #' @export
 #' @rdname scale_colour_brewer_interactive
-scale_colour_fermenter_interactive <- function(...)
+scale_colour_fermenter_interactive <- function(...) {
   scale_interactive(scale_colour_fermenter, ...)
+}
 
 #' @export
 #' @rdname scale_colour_brewer_interactive
@@ -53,5 +58,6 @@ scale_color_fermenter_interactive <- scale_colour_fermenter_interactive
 
 #' @export
 #' @rdname scale_colour_brewer_interactive
-scale_fill_fermenter_interactive <- function(...)
+scale_fill_fermenter_interactive <- function(...) {
   scale_interactive(scale_fill_fermenter, ...)
+}
