@@ -15,25 +15,30 @@
 #' @export
 #' @name scale_shape_interactive
 #' @family interactive scale
-scale_shape_interactive <- function(...)
+scale_shape_interactive <- function(...) {
   scale_interactive(scale_shape, ...)
+}
 
 #' @export
 #' @rdname scale_shape_interactive
-scale_shape_continuous_interactive <- function(...)
+scale_shape_continuous_interactive <- function(...) {
   scale_interactive(scale_shape_continuous, ...)
+}
 
 #' @export
 #' @rdname scale_shape_interactive
-scale_shape_discrete_interactive <- function(...)
+scale_shape_discrete_interactive <- function(...) {
   scale_interactive(scale_shape_discrete, ...)
+}
 
 #' @export
 #' @rdname scale_shape_interactive
-scale_shape_binned_interactive <- function(...)
+scale_shape_binned_interactive <- function(...) {
   scale_interactive(scale_shape_binned, ...)
+}
 
 #' @export
 #' @rdname scale_shape_interactive
-scale_shape_ordinal_interactive <- function(...)
+scale_shape_ordinal_interactive <- function(...) {
   scale_interactive(scale_shape_ordinal, ...)
+}
